Auction page code:
<?php
session_start();
require_once 'components/head.php';
require_once 'components/header.php';
require_once 'components/footer.php';
require_once 'functions/functions.php';
require_once 'functions/sanitize.php';

echo genereerHead();

$db = connect();
$searchKeyword = '';

if (isset($_GET['searchKeyword'])) {
    $searchKeyword = sanitize($_GET['searchKeyword']);
}

// Split the search phrase into individual words
$searchWords = explode(" ", $searchKeyword);

//Check how many active auctions there are.
$queryResults = "SELECT COUNT(*) FROM Voorwerp WHERE actief = 'j'";

$nbOfResults = $db->query($queryResults)->fetchColumn();

//Max amount of auctions that are displayed on one page.
$maxItemsPerPage = 25;

$nbOfPages = intval($nbOfResults / $maxItemsPerPage);

//If there are more than 0 auctions left, make a new page.
if(($maxItemsPerPage % $nbOfResults) !== 0){
  $nbOfPages += 1;
}

$currentPage = isset($_GET['page']) ? $_GET['page'] : 1; //Current page, if no current page given the current page is changed to 1.

$offset = ($currentPage - 1) * $maxItemsPerPage;

$pagination = [];

if($currentPage !==1){
  $pagination[] = [
    'page' => '&laquo', // << Icon
    'link' => '?page='. ($currentPage - 1) . (isset($_GET['category']) ? '&category=' . $_GET['category']: '') . (isset($_GET['minPrice']) ? '&minPrice=' . $_GET['minPrice'] : '') . (isset($_GET['maxPrice']) ? '&maxPrice=' . $_GET['maxPrice'] : ''), //Adds filters to URL
    'active' => false,
  ];
}

for($i = 1; $i <= $nbOfPages; $i++) {
  $pagination[] = [
    'page' => $i,
    'link' => '?page=' . $i . (isset($_GET['category']) ? '&category=' . $_GET['category']: '') . (isset($_GET['minPrice']) ? '&minPrice=' . $_GET['minPrice'] : '') . (isset($_GET['maxPrice']) ? '&maxPrice=' . $_GET['maxPrice'] : ''),
    'active' => ($i === $currentPage),
];
}

if ($currentPage !== $nbOfPages) {
   $pagination[] = [
       'page' => '&raquo', // >> Icon
       'link' => '?page=' . ($currentPage + 1) . (isset($_GET['category']) ? '&category=' . $_GET['category']: '') . (isset($_GET['minPrice']) ? '&minPrice=' . $_GET['minPrice'] : '') . (isset($_GET['maxPrice']) ? '&maxPrice=' . $_GET['maxPrice'] : ''),
       'active' => false,
   ];
}

$query = "SELECT Voorwerpnummer, Titel, StartPrijs, Categorie, Thumbnail, Postcode, LandAfkorting
          FROM Voorwerp
          WHERE actief = 'j'";

if (!empty($searchKeyword)) { //For each word make a search adding 'Or' if there are multiple keywords.
    $query .= " AND (";
    for ($i = 0; $i < count($searchWords); $i++) {
        if ($i > 0) {
            $query .= " OR ";
        }
        $query .= "Titel LIKE :search$i";
    }
    $query .= ")";
}

if (!empty($_GET['category']) && $_GET['category'] != 'Categorie') {
    $category = $_GET['category'];
    $query .= " AND Categorie = $category";
}

if (!empty($_GET['minPrice']) && !empty($_GET['maxPrice'])) {
    $minPrice = floatval($_GET['minPrice']);
    $maxPrice = floatval($_GET['maxPrice']);
    $query .= " AND StartPrijs BETWEEN :minPrice AND :maxPrice";
}

if (!empty($_GET['maxLatitude']) && !empty($_GET['minLatitude']) && !empty($_GET['maxLongitude']) && !empty($_GET['minLongitude'])) {
    $maxLatitude=floatval($_GET['maxLatitude']);
    $minLatitude=floatval($_GET['minLatitude']);
    $maxLongitude=floatval($_GET['maxLongitude']);
    $minLongitude=floatval($_GET['minLongitude']);
    $query .= " AND Latitude BETWEEN '$minLatitude' AND '$minLatitude' AND Longtitude BETWEEN '$maxLongitude' AND '$minLongitude'";
}

$query .= " ORDER BY Voorwerpnummer DESC
          OFFSET $offset ROWS FETCH NEXT $maxItemsPerPage ROWS ONLY";

$data = $db->prepare($query);

if (!empty($searchKeyword)) { //Bind each keyword to parameter.
    for ($i = 0; $i < count($searchWords); $i++) {
        $searchParam = "%{$searchWords[$i]}%";
        $data->bindParam(":search$i", $searchParam);
    }
}

if (isset($minPrice) && isset($maxPrice)) {
    $data->bindParam(':minPrice', $minPrice);
    $data->bindParam(':maxPrice', $maxPrice);
}

$data->execute();

$article = "";
while ($row = $data->fetch()) {
    $articleNumber = $row['Voorwerpnummer'];
    $title = $row['Titel'];
    $startingBid = round($row['StartPrijs'], 2);
    $thumbnail = $row['Thumbnail'];
    $zipCode = $row['Postcode'];
    $countryInShort = $row['LandAfkorting'];

    if (!empty($thumbnail)) {
        $isFromUpload = false;
        $uploadedImages = scandir("./images/auctionImg");
        foreach ($uploadedImages as $uploadImage) {
            if ($thumbnail == $uploadImage) {
                $isFromUpload = true;
                break; // No need to continue the loop if thumbnail is found.
            }
        }
        // Set the image source based on whether it's uploaded by a user or already in the db.
        if ($isFromUpload) {
            $img = "<img src='images/auctionImg/$thumbnail' class='w-100' alt='$thumbnail'>";
        } else {
            $img = "<img src='https://iproject6.ip.aimsites.nl/thumbnails/$thumbnail' class='w-100' alt='$thumbnail'>";
        }
    }
    $article .= "<div class='flexboxartcle'>
                <div class='row g-0 bg-body-secondary position-relative'>
                    <div class='col-md-6 mb-md-0 p-md-4'>
                        $img
                    </div>
                    <div class='col-md-6 p-4 ps-md-0'>";

    $htmlH5 = "<h5 class='mt-0 fontbold'>$title</h5>";
    $htmlP = "<p class='font'>Startbod: $startingBid</p>";
    $htmlA = "<a href='auctionDetail.php?voorwerpnummer=$articleNumber' class='btn btn-primary'>Bekijk details</a>";
    $article .= $htmlH5 . $htmlP . $htmlA . '</div> </div>';
}

$article .= "</div>
            </div>
            </div>";

// $filterCategory = isset($_POST['categoryFilter']);

// switch ($filterCategory) {
//   case '1':
//     $query .= ' ORDER BY vertrektijd DESC, vluchtnummer ASC';
//     break; 
//     case '2':
//       $query .= ' ORDER BY vertrektijd ASC, vluchtnummer ASC';
//       break;
// }
?>

<script type="text/javascript"> //Code from https://bootstrap-menu.com/detail-multilevel.html
//  window.addEventListener("resize", function() {
//      "use strict"; window.location.reload(); 
//  });

    document.addEventListener("DOMContentLoaded", function(){
        

        /////// Prevent closing from click inside dropdown
        document.querySelectorAll('.dropdown-menu').forEach(function(element){
            element.addEventListener('click', function (e) {
              e.stopPropagation();
            });
        })


        // make it as accordion for smaller screens
        if (window.innerWidth < 992) {

            // close all inner dropdowns when parent is closed
            document.querySelectorAll('.navbar .dropdown').forEach(function(everydropdown){
                everydropdown.addEventListener('hidden.bs.dropdown', function () {
                    // after dropdown is hidden, then find all submenus
                      this.querySelectorAll('.submenu').forEach(function(everysubmenu){
                        // hide every submenu as well
                        everysubmenu.style.display = 'none';
                      });
                })
            });
            
            document.querySelectorAll('.dropdown-menu a').forEach(function(element){
                element.addEventListener('click', function (e) {
        
                    let nextEl = this.nextElementSibling;
                    if(nextEl && nextEl.classList.contains('submenu')) {    
                        // prevent opening link if link needs to open dropdown
                        e.preventDefault();
                        console.log(nextEl);
                        if(nextEl.style.display == 'block'){
                            nextEl.style.display = 'none';
                        } else {
                            nextEl.style.display = 'block';
                        }
                          window.onload = function() {
    // Function to execute when the page loads
    if (navigator.geolocation) {
        navigator.geolocation.getCurrentPosition(success, error);
    } else {
        console.error("Geolocation is not supported by your browser.");
    }

    function success(position) {
        const latitude = position.coords.latitude;
        const longitude = position.coords.longitude;
        console.log(`Latitude: ${latitude}, Longitude: ${longitude}`);

        // Setting cookies
        document.cookie = "latitude=" + latitude + "; path=/";
        document.cookie = "longitude=" + longitude + "; path=/";
    }
 
    function error(err) {
        // Handle errors
        console.error(`Error (${err.code}): ${err.message}`);
    }
};
                    }
                });
            })
        }
        // end if innerWidth

    }); 
    // DOMContentLoaded  end
</script>
<body>
    <?= genereerHeader(isset($_SESSION['user']) ? $_SESSION['user'] : "", isset($_SESSION['messageCount']) ? count($_SESSION['messageCount']) : "") ?>
    <main>
        <div class="auctioncontainer">
            <!-- Start search container -->
            <div class="searchcontainer">
            <form class="search-form-container" method="GET" action="auctionPage.php">
                    <input type="hidden" name="page" value="1"> <!-- Include page parameter in the URL, sets page to 1 -->
                    <input type="hidden" name="category" value="<?= isset($_GET['category']) ? $_GET['category'] : '' ?>"><!-- Include category parameter in the URL -->
                    <input type="text" name="maxLatitude" value="">
                    


                    <h2 class="fontbold text-center">Filters</h3>
                    <!-- Categories -->
                    <nav class="nav-item">
                      <ul class="btn btn-primary width100 font">
                          <li class="dropdown">
                            <a class="dropdown-toggle fontbold nav-link active" href="#" data-bs-toggle="dropdown">Categoriën</a>
                              <ul class="dropdown-menu">
                                  <?php echo fetchCategories($db);?>
                              </ul>
                          </li>
                      </ul>
                    </nav>

                    <!-- Pricefilters -->
                    <h3 class="fontbold">Prijs</h3>
                    <div class="search-form">
                        <div class="input-group mb-3">
                            <span class="input-group-text">Van €</span>
                            <input type="text" class="form-control" aria-label="Amount (to the nearest dollar)"
                                name="minPrice">
                        </div>
                        <div class="input-group mb-3">
                            <span class="input-group-text">Tot €</span>
                            <input type="text" class="form-control" aria-label="Amount (to the nearest dollar)"
                                name="maxPrice">
                        </div>
                    </div>

                    <!-- Sorting price low to high -->
                    <!-- <h3 class="fontbold">Sorteer op prijs</h3>
                    <div class="search-form">
                        <div class="form-check">
                            <input class="form-check-input" type="radio" name="flexRadioDefault" id="flexRadioDefault1">
                            <label class="form-check-label" for="flexRadioDefault1">
                                <p class="font">
                                    Laag naar hoog
                                </p>
                            </label>
                        </div>
                        <div class="form-check">
                            <input class="form-check-input" type="radio" name="flexRadioDefault" id="flexRadioDefault2"
                                checked>
                            <label class="form-check-label" for="flexRadioDefault2">
                                <p class="font">
                                    Hoog naar laag
                                </p>
                            </label>
                        </div>
                    </div> -->

                    <!-- Slider max km distance -->
                    <?php if(!empty($_SESSION['user'])): ?>
                      <h3 class="fontbold">Maximum afstand</h3>

                      <input type="range" min="0" max="500" value="10" class="slider btn"
                          oninput="rangeValue.innerText = this.value" name="km">
                      <div class="km">
                          <p id="rangeValue">10</p>
                          <p>km</p>
                      </div>
                    <?php endif ?>
                    <!-- Search button and reset button -->
                    <div class="search-form displayflexbuttons">
                      <input class="btn btn-primary searchcontainerbutton" type="submit" value="Zoek">
                      <a href="auctionPage.php?page=1" class="btn btn-primary cyan-btn searchcontainerbutton">Reset</a>
                    </div>
                </form>
            </div>
            <!-- Item -->
            <?= $article ?>
            <nav aria-label="Auction results">
                <ul class="pagination">
                    <?php foreach ($pagination as $index => $page): ?> <!--$index is used to determine the posistion of each button -->
                        <?php if ($index === 0): ?> <!-- Checks if current button is first in the array -->
                            <li class="page-item<?= $page['active']?>">
                                <a class="page-link" href="<?= $page['link'] ?>"><?= $page['page'] ?></a>
                            </li>
                        <?php endif; ?>
                        <?php if ($page['page'] == $currentPage): ?> <!-- Checks if current button for current page-->
                            <li class="page-item active<?= $page['active']?>">
                                <a class="page-link" href="<?= $page['link'] ?>"><?= $page['page'] ?></a>
                            </li>
                        <?php endif; ?>
                        <?php if ($page['page'] === $currentPage - 1 || $page['page'] === $currentPage || $page['page'] === $currentPage + 1): ?> <!-- Checks if button is before or after current button-->
                            <li class="page-item <?= $page['active'] ?>">
                                <a class="page-link" href="<?= $page['link'] ?>"><?= $page['page'] ?></a>
                            </li>
                        <?php endif; ?>
                        <?php if ($index === count($pagination) - 2): ?> <!-- Checks if current button is second-to-last button in the pagination array-->
                            <li class="page-item disabled">
                                <a class="page-link" href="#">&hellip;</a> <!-- ... icon -->
                            </li>
                        <?php endif; ?>
                        <?php if ($index === count($pagination) - 1): ?> <!-- Checks if current button is last one in the pagination array-->
                            <li class="page-item <?= $page['active']?>">
                                <a class="page-link" href="<?= $page['link'] ?>"><?= $page['page'] ?></a>
                            </li>
                        <?php endif; ?>
                    <?php endforeach; ?>
                </ul>
            </nav>
        </div>
    </main>
    <a href="#" class="top font nav-link">Terug naar boven &#8593;</a>
    <?= genereerfooter(); ?>
</body>

</html>


Auction create code:

<?php
    session_start();
    require_once 'db_connectie.php';
    require_once 'components/head.php';
    require_once 'components/header.php';
    require_once 'components/footer.php';
    require_once 'functions/sanitize.php';

    // Check if the session user is a 'verkoper'
    $db = connect();
    $query = "SELECT verkoper 
                FROM Gebruiker 
                WHERE gebruikersnaam = :username AND verkoper = 'j'";
    $data = $db->prepare($query);

    $data->bindParam(':username', $_SESSION['user']);

    $data->execute();

    $result = $data->fetch();

    // user isn't a seller
    if (!$result) {
        $_SESSION['messages'] = 'De verkooppagina is alleen zichtbaar voor verkopers.';
        header("location:homePage.php");
        die;
    }else{// User is a seller
        $categoryNum =  '';

        if(isset($_POST['insert'])) {
            $fouten = [];
            $thumbnail = $_FILES['thumbnail']['name'];
            $title = sanitize(ucfirst($_POST['title']));
            $endDate = $_POST['endDate'];
            $startBid = $_POST['startBid'];
            $category = $_POST['category'];
            $paymentType = $_POST['paymentType'];
            $paymentInstruction = sanitize(ucfirst($_POST['paymentInstruction']));
            $condition = $_POST['condition'];
            $valuta = $_POST['valuta'];
            $shippingPrice = $_POST['shippingPrice'];
            $shippingInstruction = sanitize(ucfirst($_POST['shippingInstruction']));
            $description = sanitize(ucfirst($_POST['description']));

            //Designated directory
            $destinationT = __DIR__. "/images/auctionImg/" .$thumbnail ;

            //Saves thumbnail in file
            move_uploaded_file($_FILES['thumbnail']["tmp_name"],$destinationT);

            if (!isset($thumbnail) || !isset($title) || !isset($endDate) || !isset($startBid) || !isset($valuta) || !isset($category) || !isset($paymentType) || !isset($condition) || !isset($description)) {
            $fouten[] = 'Niet alle verplichte velden zijn ingevuld.';
            }
            $message = '';
            if(count($fouten) > 0) {
                $message = "Er waren fouten in de invoer.<ul>";
                foreach($fouten as $fout) {
                $message .= "<li>$fout</li>";
                }
                $message .= "</ul>";

            } else {
                $db = connect();

                $queryMaxId = "SELECT MAX(Voorwerpnummer) AS maxId 
                                FROM Voorwerp";
                $dataMaxId = $db->prepare($queryMaxId);
                $dataMaxId->execute();
                $maxIdResult = $dataMaxId->fetch();
                $maxId = $maxIdResult['maxId'];
        
                $nextId = $maxId + 1;    

                $queryUser = 'SELECT Postcode, Landnaam, LandAfkorting
                            FROM Gebruiker 
                            WHERE Gebruikersnaam = :username';
                $dataUser = $db->prepare($queryUser);

                $dataUser->bindParam(':username', $_SESSION['user']);

                $dataUser->execute();
                $userData = $dataUser->fetch();

                $zipCode = $userData['Postcode'];
                $country = $userData['Landnaam'];
                $countryInShort = $userData['LandAfkorting'];

                $queryItem = 'INSERT INTO Voorwerp(Voorwerpnummer, Titel, LooptijdInDagen, Beschrijving, Categorie, Postcode, Land, LandAfkorting, Verkoper, 
                            Betalingswijzenaam, Betalingsinstructie, Valuta, Startprijs, Verzendkosten, Verzendinstructies, Conditie, Thumbnail)
                            VALUES (:id, :title, :endDate, :description, :category, :zipCode, :country, :countryInShort, :seller, 
                            :paymentType, :paymentInstruction, :valuta, :startBid, :shippingPrice, :shippingInstruction, :condition, :thumbnail)';

                $dataItem = $db->prepare($queryItem);

                $dataArrayItem = [
                    ':id' => $nextId,
                    ':title' => $title, 
                    ':endDate' => $endDate,
                    ':description' => $description,
                    ':category' => $category,
                    ':zipCode' => $zipCode,
                    ':country' => $country,
                    ':countryInShort' => $countryInShort,
                    ':seller' => $_SESSION['user'],
                    ':paymentType' => $paymentType,
                    ':paymentInstruction' => $paymentInstruction, 
                    ':valuta' => $valuta,
                    ':startBid' => floatval($startBid), 
                    ':shippingPrice' => floatval($shippingPrice),
                    ':shippingInstruction' => $shippingInstruction, 
                    ':condition' => $condition,
                    ':thumbnail' => $thumbnail,
                ];

                $successItem = $dataItem->execute($dataArrayItem);

                if(!$successItem){
                    $message = 'Veiling toevoegen is mislukt, fout met voorwerp.';
                }else{
                    $queryThumbnail = 'INSERT INTO Bestand(Voorwerp, Filenaam)
                    VALUES (:item, :filename)';

                    $dataThumbnail = $db->prepare($queryThumbnail);

                    $dataArrayThumbnail = [
                        ':item' => $nextId,
                        ':filename' => $thumbnail, 
                    ];

                    $successThumbnail = $dataThumbnail->execute($dataArrayThumbnail);
                    if(!$successThumbnail){
                        $message = 'Veiling toevoegen is mislukt, fout met thumbnail.';
                    }else{
                        if(count($_FILES['image']['name']) < 6){ //Max amount of files is 6
                            // Loop through each submitted image file
                            for($i = 0; $i < count($_FILES['image']['name']); $i++) { // https://techareatutorials.com/multiple-image-upload-in-php-and-mysql/
                                // Get the filename and temporary file path
                                $filename = basename($_FILES['image']['name'][$i]);
                                $uploadfile = $_FILES['image']['tmp_name'][$i];
                                
                                // Move the uploaded file to the destination directory
                                $destinationI = __DIR__. "/images/auctionImg/" .$filename;
                                move_uploaded_file($uploadfile, $destinationI);
        
                                $queryImage = "INSERT INTO Bestand(Voorwerp, Filenaam) 
                                                VALUES (:item, :filename)";
                                $dataImage = $db->prepare($queryImage);
                                
                                $dataArrayImage = [
                                    ':item' => $nextId,
                                    ':filename' => $filename,
                                ];
                                
                                $successImage = $dataImage->execute($dataArrayImage);
                                
                                if(!$successImage) {
                                    $message = "Veiling toevoegen is mislukt, fout met foto's.";
                                }else{
                                    $message = 'Veiling is toegevoegd.';
                                }
                            }
                        }else{
                            $message = "Het maximaal aantal foto's dat toegevoegd mag worden is 6.";
                        }
                        
                function updateCoordinates($db) {
                    global $conn;  // Assuming $conn is globally defined if not being passed as an argument
                
                    // SQL query to select entries with NULL latitude or Longtitude, excluding 'TestAdres1'
                    $sql = "SELECT V.Voorwerpnummer, G.Adresregel1, G.Landnaam, G.Plaatsnaam
                            FROM dbo.Voorwerp V
                            INNER JOIN dbo.Gebruiker G ON V.Verkoper = G.Gebruikersnaam
                            WHERE (V.Latitude IS NULL OR V.Longtitude IS NULL)
                            AND G.Adresregel1 != 'TestAdres1'";
                
             

                    $result = $db->prepare($sql);
                    $result->execute();

                
                    while ($row = $result->fetch()) {
                        // Formulate the Google Maps API request
                        $locality = urlencode($row['Adresregel1']);
                        $country = urlencode($row['Landnaam']);
                        $plaatsnaam = urlencode($row['Plaatsnaam']);
                        $voorwerpnummer = urlencode($row['Voorwerpnummer']);
                        //$apiUrl = "https://maps.googleapis.com/maps/api/geocode/json?components=locality:Arnhem|country:NL&key=AIzaSyBKDIaVvRqAr6COWjkPsGHpujP6BcALL9Ap";
                        $apiUrl = "https://maps.googleapis.com/maps/api/geocode/json?components=route:$locality|administrative_area:$plaatsnaam|country:$country&key=AIzaSyBKDIaVvRqAr6COWjkPsGHpujP6BcALL9A";
                        // Fetch the response from Google Maps API
                        $response = file_get_contents($apiUrl);
                        $data = json_decode($response, true);
                       
                        if ($data['status'] == 'OK' && !empty($data['results'])) {
                            $latitude = $data['results'][0]['geometry']['location']['lat'];
                            $Longtitude = $data['results'][0]['geometry']['location']['lng'];
                
                            // pi the database with the new coordinates
                            $updateSql = "UPDATE dbo.Voorwerp SET Latitude = $latitude, Longtitude = $Longtitude WHERE Voorwerpnummer = $voorwerpnummer";
                            $updateStmt = $db->prepare($updateSql);
                            //$updateStmt->bindParam("ddi", $latitude, $Longtitude, $row['Voorwerpnummer']);
                            $updateStmt->execute();
                        } else {
                            echo "No valid coordinates found for " . $row['Adresregel1'] . ", " . $row['Landnaam'] . "\n";
                            //echo $data['results'][0]['geometry']['location']['lng'];;
                        }
                    }
                
                  
                }
                updateCoordinates($db);
                
                
                // Check if insertion was successful
                if(!$successImage) {
                    // Handle error
                    $message = "Veiling toevoegen is mislukt, fout met foto's.";
                    // You might want to break out of the loop here or handle the error differently
                }else{
                    $message = 'Veiling is toegevoegd.';

                }
            }
        }
                    }
                }
            }
    

    echo genereerHead();
?>

<body>
    <?= genereerHeader(isset($_SESSION['user']) ? $_SESSION['user'] : "", isset($_SESSION['messageCount']) ? count($_SESSION['messageCount']) : "") ?>
    <main>
        <?php if (!empty($message)): ?>
            <div class="msg-container">
                <p class="font">
                    <b><?= $message ?></b><br>
                </p>
            </div>
        <?php endif; ?>
        <form class="row g-3" method="POST" action="" enctype="multipart/form-data"> <!-- Enctype specified because a file is used -->
            <h1>Maak een nieuwe veiling</h1>
            <p class="form-label font ">Velden met een * zijn verplicht.</p>
            
            <!-- Auction pictures -->
            <div class="col-md-6">
                <h3 class="formFile fontbold">Max. 1 Thumbnail*</h3>
                <input class="form-control font choosepic" type="file" id="formFile" name="thumbnail" required>
            </div>
            <div class="col-md-6">
                <h3 class="formFile fontbold">Max. 6 foto('s)*</h3>
                <input class="form-control font choosepic" type="file" id="formFileMultiple" name="image[]" multiple required>
            </div>
            <!-- Auction title -->
            <div class="col-md-6">
                <label for="inputTitle" class="form-label font">Titel*:</label>
                <input type="text" class="form-control font" placeholder="Hondenspeelgoed" name="title" required>
            </div>

            <!-- Auction enddate -->
            <div class="col-md-6">
            <label for="inputCategory" class="form-label font">Einddatum*:</label>
            <select id="inputCategory" class="form-select font" name="endDate" required>
                <option selected>Kies een einddatum</option>
                <option value="7">Over 1 week</option>
                <option value="14">Over 2 weken</option>
                <option value="21">Over 3 weken</option>
                <option value="28">Over 4 weken</option>
            </select>
            </div>

            <!-- Startbid -->
            <div class="col-md-3">
                <label for="inputStartBid" class="form-label font">Startprijs*:</label>
                <input type="number" class="form-control font" placeholder="100" id="inputStartBid" name="startBid" required>
            </div>

            <div class="col-md-3">
                <label for="inputValuta" class="form-label font">Valuta*:</label>
                <select id="inputValuta" class="form-select font" name="valuta" required>
                    <option selected>Kies een valuta</option>
                    <?php
                        $queryValuta = 'SELECT DISTINCT Valuta
                                        FROM Voorwerp';
                        $dataValuta = $db->prepare($queryValuta);
                        $dataValuta->execute();
                        // Generate options for each category
                        while ($row = $dataValuta->fetch()) {
                            $valutaName = $row['Valuta'];
                            echo "<option value='$valutaName'>$valutaName</option>";
                        }
                    ?>
                </select>
            </div>

            <!-- Auction category -->
            <div class="col-md-3">
                <label for="inputCategory" class="form-label font">Categorie*:</label>
                <select id="inputCategory" class="form-select font" name="category" required>
                    <option selected>Kies een categorie</option>
                    <?php
                        $queryCat = 'SELECT *
                                    FROM Rubriek
                                    ORDER BY SubRubriekVan DESC';
                        $dataCat = $db->prepare($queryCat);
                        $dataCat->execute();
                        // Generate options for each category
                        while ($row = $dataCat->fetch()) {
                            $categoryNum = $row['rubrieknummer'];
                            $categoryName = $row['rubrieknaam'];
                            if ($categoryName != 'Root') {
                                echo "<option value='$categoryNum'>$categoryName</option>";
                            }
                        }
                    ?>
                </select>
            </div> 

            <!-- Payment type-->
            <div class="col-md-3">
                <label for="paymentType" class="form-label font">Betalingswijze*:</label>
                <select id="paymentType" class="form-select font" name="paymentType" required>
                    <option selected>Kies een betalingswijze</option>
                    <option value="Creditcard">Creditcard</option>
                    <option value="Ideal">Ideal</option>
                    <option value="Cash">Contant</option>
                </select>
            </div>

            <!-- Payment instructions -->
            <div class="col-md-9">
                <label for="inputTitle" class="form-label font">Betalingsinstructie:</label>
                <input type="text" class="form-control font" placeholder="Betalingsinstructie" name="paymentInstruction">
            </div>

            <!-- Shipping fees -->

            <div class="col-md-3">
                <label for="condition" class="form-label font">Conditie:</label>
                <select id="condition" class="form-select font" name="condition" required>
                    <option selected>Kies een conditie</option>
                    <option value="Nieuw">Nieuw</option>
                    <option value="ZGAN">Zo goed als nieuw</option>
                    <option value="Tweedehands">Tweedehands</option>
                </select>
            </div>

            <!-- Shipping instructions -->
            <div class="col-md-8">
                <label for="inputTitle" class="form-label font">Verzendinstructies:</label>
                <input type="text" class="form-control font" placeholder="PostNL" name="shippingInstruction">
            </div>

            <div class="col-md-4">
                <label for="inputTitle" class="form-label font">Verzendkosten:</label>
                <input type="number" class="form-control font" placeholder="5" name="shippingPrice">
            </div>

            <!-- Description -->
            <div class="col-md-6 max-width">
                <label for="inputDescription" class="form-label font ">Beschrijving*:</label>
                <textarea class="form-control " id="exampleFormControlTextarea1" rows="1" name="description" placeholder="Speelgoed voor een grote hond" required></textarea>
            </div>
        
            <!-- Buttons to save or cancel -->
            <div class="displayflexbuttons buttonsuserchange">
                <button type="submit" class="btn btn-primary width100 font cyan-btn" name="insert">Plaatsen</button>
            </div>
        </form>
        <a href="profile.php" class="btn btn-primary width100 font">Annuleren</a>
        </div>
    </main>
    <a href="#" class="top font nav-link">Terug naar boven &#8593;</a>
    <?= genereerFooter(); ?>
</body>

</html>

